# Changelog

<!--next-version-placeholder-->

## v0.27.0 (2023-03-30)
### Feature
* Pass through variables to summarise and query ([`d515737`](https://github.com/rob-luke/conversations/commit/d515737bc294d0179d58e21c67b6f967adebdebc))

## v0.11.0 (2022-12-18)
### Feature
* Generate reports ([`fd5ea4c`](https://github.com/rob-luke/conversations/commit/fd5ea4c802d79cc4970afdb597052a1a24e99477))

## v0.10.0 (2022-12-18)
### Feature
* Add transcription using whisper ([`a9ede7c`](https://github.com/rob-luke/conversations/commit/a9ede7c7b687a592f922475239892d4715005066))

### Documentation
* Use mkdocs for documentation ([`d2b3b0a`](https://github.com/rob-luke/conversations/commit/d2b3b0aa0e7bc77d2e65c8c0827ebf69b5e29c51))

## v0.9.0 (2022-11-25)
### Feature
* Improve commit title for releases ([`78965c3`](https://github.com/rob-luke/conversations/commit/78965c30d8417bff645d237d658638a8e063351b))

## v0.8.0 (2022-11-25)
### Feature
* What happens if we have a longer message ([`77a2cce`](https://github.com/rob-luke/conversations/commit/77a2cce16a1681568eedd1b974cc99ef8a1de808))

## v0.7.0 (2022-11-25)
### Feature
* Update committer name ([`23a2318`](https://github.com/rob-luke/conversations/commit/23a2318b4c0c8df637663fd4ccedd1135caa801d))

## v0.6.0 (2022-11-25)
### Feature
* Commit changes to github ([`a9d06d5`](https://github.com/rob-luke/conversations/commit/a9d06d5747ce36074831cb779af199f5f1ba366d))
